@@ -14,19 +14,17 @@ from openhcs.microscopes.microscope_base import create_microscope_handler
 
 # Import registry service for automatic discovery
 from openhcs.microscopes.handler_registry_service import (
-    discover_all_handlers,
     get_all_handler_types,
     is_handler_available
 )
 
-# Note: Individual handlers are automatically discovered and registered via metaclass.
-# No hardcoded imports needed - the discovery system handles everything automatically.
+# Note: Individual handlers are automatically discovered via LazyDiscoveryDict on first access.
+# No hardcoded imports or explicit discovery calls needed.
 
 __all__ = [
     # Factory function - primary public API
     'create_microscope_handler',
     # Registry service functions
-    'discover_all_handlers',
     'get_all_handler_types',
     'is_handler_available',
 ]
