@@ -63,9 +63,6 @@ class OpenHCSMainWindow(QMainWindow):
         # Settings for window state persistence
         self.settings = QSettings("OpenHCS", "PyQt6GUI")
 
-        # Initialize Log Viewer on startup (hidden) for continuous log monitoring
-        self._initialize_log_viewer()
-        
         # Initialize UI
         self.setup_ui()
         self.setup_dock_system()
@@ -80,11 +77,28 @@ class OpenHCSMainWindow(QMainWindow):
         # Restore window state
         self.restore_window_state()
 
-        # Show default windows (plate manager and pipeline editor visible by default)
+        logger.info("OpenHCS PyQt6 main window initialized (deferred initialization pending)")
+
+    def _deferred_initialization(self):
+        """
+        Deferred initialization that happens after window is visible.
+
+        This includes:
+        - Log viewer initialization (file I/O) - IMMEDIATE
+        - Default windows (pipeline editor with config cache warming) - IMMEDIATE
+
+        Note: System monitor is now created during __init__ so startup screen appears immediately
+        """
+        # Initialize Log Viewer (hidden) for continuous log monitoring - IMMEDIATE
+        self._initialize_log_viewer()
+
+        # Show default windows (plate manager and pipeline editor visible by default) - IMMEDIATE
         self.show_default_windows()
 
-        logger.info("OpenHCS PyQt6 main window initialized")
-    
+        logger.info("Deferred initialization complete (UI ready)")
+
+
+
     def setup_ui(self):
         """Setup basic UI structure."""
         self.setWindowTitle("OpenHCS")
@@ -92,17 +106,20 @@ class OpenHCSMainWindow(QMainWindow):
 
         # Make main window floating (not tiled) like other OpenHCS components
         self.setWindowFlags(Qt.WindowType.Dialog)
-        
-        # Central widget with system monitor background
+
+        # Central widget with system monitor (shows startup screen immediately)
         central_widget = QWidget()
         central_layout = QVBoxLayout(central_widget)
         central_layout.setContentsMargins(0, 0, 0, 0)
-        
-        # System monitor widget (background)
+
+        # Create system monitor immediately so startup screen shows right away
         from openhcs.pyqt_gui.widgets.system_monitor import SystemMonitorWidget
         self.system_monitor = SystemMonitorWidget()
         central_layout.addWidget(self.system_monitor)
-        
+
+        # Store layout for potential future use
+        self.central_layout = central_layout
+
         self.setCentralWidget(central_widget)
 
     def apply_initial_theme(self):
@@ -141,12 +158,13 @@ class OpenHCSMainWindow(QMainWindow):
         self.floating_windows = {}  # Track created windows
 
     def show_default_windows(self):
-        """Show plate manager and pipeline editor by default (like Textual TUI)."""
+        """Show plate manager by default."""
         # Show plate manager by default
         self.show_plate_manager()
 
-        # Show pipeline editor by default
-        self.show_pipeline_editor()
+        # Pipeline editor is NOT shown by default because it imports ALL GPU libraries
+        # (torch, tensorflow, jax, cupy, pyclesperanto) which takes 8+ seconds
+        # User can open it from View menu when needed
 
     def show_plate_manager(self):
         """Show plate manager window (mirrors Textual TUI pattern)."""
@@ -170,6 +188,27 @@ class OpenHCSMainWindow(QMainWindow):
 
             self.floating_windows["plate_manager"] = window
 
+            # Connect progress signals to status bar
+            if hasattr(self, 'status_bar') and self.status_bar:
+                # Create progress bar in status bar if it doesn't exist
+                if not hasattr(self, '_status_progress_bar'):
+                    from PyQt6.QtWidgets import QProgressBar
+                    self._status_progress_bar = QProgressBar()
+                    self._status_progress_bar.setMaximumWidth(200)
+                    self._status_progress_bar.setVisible(False)
+                    self.status_bar.addPermanentWidget(self._status_progress_bar)
+
+                # Connect progress signals
+                plate_widget.progress_started.connect(
+                    lambda max_val: self._on_plate_progress_started(max_val)
+                )
+                plate_widget.progress_updated.connect(
+                    lambda val: self._on_plate_progress_updated(val)
+                )
+                plate_widget.progress_finished.connect(
+                    lambda: self._on_plate_progress_finished()
+                )
+
             # Connect to pipeline editor if it exists (mirrors Textual TUI)
             self._connect_plate_to_pipeline_manager(plate_widget)
 
@@ -297,7 +336,6 @@ class OpenHCSMainWindow(QMainWindow):
         """Show ZMQ server manager window."""
         if "zmq_server_manager" not in self.floating_windows:
             from openhcs.pyqt_gui.widgets.shared.zmq_server_manager import ZMQServerManagerWidget
-            from openhcs.constants.constants import DEFAULT_NAPARI_STREAM_PORT
 
             # Create floating window
             window = QDialog(self)
@@ -308,13 +346,10 @@ class OpenHCSMainWindow(QMainWindow):
             # Add widget to window
             layout = QVBoxLayout(window)
 
-            # Scan common ports:
-            # - 7777: Default ZMQ execution server
-            # - 5555-5564: Napari viewers (10 ports)
-            # - 5565-5574: Fiji viewers (10 ports, non-overlapping with Napari)
-            napari_ports = [DEFAULT_NAPARI_STREAM_PORT + i for i in range(10)]
-            fiji_ports = [5565 + i for i in range(10)]  # 5565-5574 (avoid overlap with Napari)
-            ports_to_scan = [7777] + napari_ports + fiji_ports
+            # Scan all streaming ports using current global config
+            # This ensures we find viewers launched with custom ports
+            from openhcs.core.config import get_all_streaming_ports
+            ports_to_scan = get_all_streaming_ports(num_ports_per_type=10)  # Uses global config by default
 
             zmq_manager_widget = ZMQServerManagerWidget(
                 ports_to_scan=ports_to_scan,
@@ -442,7 +477,6 @@ class OpenHCSMainWindow(QMainWindow):
 
         view_menu.addSeparator()
 
-
         # Help menu
         help_menu = menubar.addMenu("&Help")
 
@@ -656,24 +690,25 @@ class OpenHCSMainWindow(QMainWindow):
         """
         from pathlib import Path
 
+        # Ensure plate manager exists (create if needed)
+        self.show_plate_manager()
+
         # Get the plate manager widget
-        if "plate_manager" in self.floating_windows:
-            plate_dialog = self.floating_windows["plate_manager"]
-            from openhcs.pyqt_gui.widgets.plate_manager import PlateManagerWidget
-            plate_manager = plate_dialog.findChild(PlateManagerWidget)
+        plate_dialog = self.floating_windows["plate_manager"]
+        from openhcs.pyqt_gui.widgets.plate_manager import PlateManagerWidget
+        plate_manager = plate_dialog.findChild(PlateManagerWidget)
 
-            if plate_manager:
-                # Add the generated plate - this triggers plate_selected signal
-                # which automatically updates pipeline editor via existing connections
-                plate_manager.add_plate_callback([Path(output_dir)])
+        if not plate_manager:
+            raise RuntimeError("Plate manager widget not found after creation")
 
-                # Load the test pipeline
-                self._load_pipeline_file(pipeline_path)
+        # Add the generated plate - this triggers plate_selected signal
+        # which automatically updates pipeline editor via existing connections
+        plate_manager.add_plate_callback([Path(output_dir)])
 
-                # Show the plate manager window if it's hidden
-                self.show_plate_manager()
+        # Load the test pipeline (this will create pipeline editor if needed)
+        self._load_pipeline_file(pipeline_path)
 
-                logger.info(f"Added synthetic plate and loaded test pipeline: {output_dir}")
+        logger.info(f"Added synthetic plate and loaded test pipeline: {output_dir}")
 
     def _load_pipeline_file(self, pipeline_path: str):
         """
@@ -683,26 +718,23 @@ class OpenHCSMainWindow(QMainWindow):
             pipeline_path: Path to the pipeline file to load
         """
         try:
-            # Get the pipeline editor widget
-            if "pipeline_editor" not in self.floating_windows:
-                logger.debug("Pipeline editor not available - skipping pipeline load")
-                return
+            # Ensure pipeline editor exists (create if needed)
+            self.show_pipeline_editor()
 
+            # Get the pipeline editor widget
             pipeline_dialog = self.floating_windows["pipeline_editor"]
             from openhcs.pyqt_gui.widgets.pipeline_editor import PipelineEditorWidget
             pipeline_editor = pipeline_dialog.findChild(PipelineEditorWidget)
 
             if not pipeline_editor:
-                logger.debug("Pipeline editor widget not found - skipping pipeline load")
-                return
+                raise RuntimeError("Pipeline editor widget not found after creation")
 
             # Load the pipeline file
             from pathlib import Path
             pipeline_file = Path(pipeline_path)
 
             if not pipeline_file.exists():
-                logger.warning(f"Pipeline file not found: {pipeline_path}")
-                return
+                raise FileNotFoundError(f"Pipeline file not found: {pipeline_path}")
 
             # For .py files, read code and use existing _handle_edited_pipeline_code
             if pipeline_file.suffix == '.py':
@@ -719,6 +751,7 @@ class OpenHCSMainWindow(QMainWindow):
 
         except Exception as e:
             logger.error(f"Failed to load pipeline: {e}", exc_info=True)
+            raise
 
 
 
@@ -855,3 +888,20 @@ class OpenHCSMainWindow(QMainWindow):
                     "Theme Save Error",
                     f"Failed to save theme to {Path(file_path).name}"
                 )
+
+    def _on_plate_progress_started(self, max_value: int):
+        """Handle plate manager progress started signal."""
+        if hasattr(self, '_status_progress_bar'):
+            self._status_progress_bar.setMaximum(max_value)
+            self._status_progress_bar.setValue(0)
+            self._status_progress_bar.setVisible(True)
+
+    def _on_plate_progress_updated(self, value: int):
+        """Handle plate manager progress updated signal."""
+        if hasattr(self, '_status_progress_bar'):
+            self._status_progress_bar.setValue(value)
+
+    def _on_plate_progress_finished(self):
+        """Handle plate manager progress finished signal."""
+        if hasattr(self, '_status_progress_bar'):
+            self._status_progress_bar.setVisible(False)
