@@ -242,16 +242,30 @@ class FunctionListEditorWidget(QWidget):
     
     def _populate_function_list(self):
         """Populate function list with panes (mirrors Textual TUI)."""
-        # Clear existing panes
+        # Clear existing panes - CRITICAL: Manually unregister form managers BEFORE deleteLater()
+        # This prevents RuntimeError when new widgets try to connect to deleted managers
         for pane in self.function_panes:
-            pane.setParent(None)
+            # Explicitly unregister the form manager before scheduling deletion
+            if hasattr(pane, 'form_manager') and pane.form_manager is not None:
+                try:
+                    pane.form_manager.unregister_from_cross_window_updates()
+                except RuntimeError:
+                    pass  # Already deleted
+            pane.deleteLater()  # Schedule for deletion - triggers destroyed signal
         self.function_panes.clear()
-        
+
         # Clear layout
         while self.function_layout.count():
             child = self.function_layout.takeAt(0)
             if child.widget():
-                child.widget().setParent(None)
+                # Unregister form manager if it exists
+                widget = child.widget()
+                if hasattr(widget, 'form_manager') and widget.form_manager is not None:
+                    try:
+                        widget.form_manager.unregister_from_cross_window_updates()
+                    except RuntimeError:
+                        pass  # Already deleted
+                widget.deleteLater()  # Schedule for deletion instead of just orphaning
         
         if not self.functions:
             # Show empty state
@@ -273,7 +287,37 @@ class FunctionListEditorWidget(QWidget):
 
                 self.function_panes.append(pane)
                 self.function_layout.addWidget(pane)
+
+                # CRITICAL FIX: Apply initial enabled styling for function panes
+                # This ensures that when the function pattern editor opens, disabled functions
+                # show the correct dimmed styling immediately, not just after toggling
+                if hasattr(pane, 'form_manager') and pane.form_manager is not None:
+                    # Use QTimer to ensure this runs after the widget is fully constructed
+                    from PyQt6.QtCore import QTimer
+                    QTimer.singleShot(0, lambda p=pane: self._apply_initial_enabled_styling_to_pane(p))
     
+    def _apply_initial_enabled_styling_to_pane(self, pane):
+        """Apply initial enabled styling to a function pane.
+
+        This is called after a function pane is created to ensure that disabled functions
+        show the correct dimmed styling immediately when the function pattern editor opens.
+
+        Args:
+            pane: FunctionPaneWidget instance to apply styling to
+        """
+        try:
+            if hasattr(pane, 'form_manager') and pane.form_manager is not None:
+                # Check if the form manager has an enabled field
+                if 'enabled' in pane.form_manager.parameters:
+                    # Apply the initial enabled styling
+                    if hasattr(pane.form_manager, '_apply_initial_enabled_styling'):
+                        pane.form_manager._apply_initial_enabled_styling()
+        except Exception as e:
+            # Log error but don't crash the UI
+            import logging
+            logger = logging.getLogger(__name__)
+            logger.warning(f"Failed to apply initial enabled styling to function pane: {e}")
+
     def setup_connections(self):
         """Setup signal/slot connections."""
         pass
