@@ -432,14 +432,17 @@ class ImageBrowserWidget(QWidget):
     def _create_instance_manager_panel(self):
         """Create the viewer instance manager panel using ZMQServerManagerWidget."""
         from openhcs.pyqt_gui.widgets.shared.zmq_server_manager import ZMQServerManagerWidget
-        from openhcs.constants.constants import DEFAULT_NAPARI_STREAM_PORT
+        from openhcs.core.config import get_all_streaming_ports
 
-        # Scan Napari and Fiji ports
-        # Napari: 5555-5564 (10 ports)
-        # Fiji: 5565-5574 (10 ports, non-overlapping with Napari)
-        napari_ports = [DEFAULT_NAPARI_STREAM_PORT + i for i in range(10)]  # 5555-5564
-        fiji_ports = [5565 + i for i in range(10)]  # 5565-5574 (avoid overlap with Napari)
-        ports_to_scan = napari_ports + fiji_ports
+        # Scan all streaming ports using orchestrator's pipeline config
+        # This ensures we find viewers launched with custom ports
+        # Exclude execution server port (only want viewer ports)
+        from openhcs.constants.constants import DEFAULT_EXECUTION_SERVER_PORT
+        all_ports = get_all_streaming_ports(
+            config=self.orchestrator.pipeline_config if self.orchestrator else None,
+            num_ports_per_type=10
+        )
+        ports_to_scan = [p for p in all_ports if p != DEFAULT_EXECUTION_SERVER_PORT]
 
         # Create ZMQ server manager widget
         zmq_manager = ZMQServerManagerWidget(
@@ -455,6 +458,11 @@ class ImageBrowserWidget(QWidget):
         """Set the orchestrator and load images."""
         self.orchestrator = orchestrator
 
+        # Use orchestrator's FileManager (has plate-specific backends like VirtualWorkspaceBackend)
+        if orchestrator:
+            self.filemanager = orchestrator.filemanager
+            logger.debug("Image browser now using orchestrator's FileManager")
+
         # Update config form contexts to use new pipeline_config
         if self.napari_config_form and orchestrator:
             self.napari_config_form.context_obj = orchestrator.pipeline_config
@@ -676,13 +684,17 @@ class ImageBrowserWidget(QWidget):
             return
 
         try:
+            logger.info("IMAGE BROWSER: Starting load_images()")
             # Get metadata handler from orchestrator
             handler = self.orchestrator.microscope_handler
             metadata_handler = handler.metadata_handler
+            logger.info(f"IMAGE BROWSER: Got metadata handler: {type(metadata_handler).__name__}")
 
             # Get image files from metadata
             plate_path = self.orchestrator.plate_path
+            logger.info(f"IMAGE BROWSER: Calling get_image_files for plate: {plate_path}")
             image_files = metadata_handler.get_image_files(plate_path)
+            logger.info(f"IMAGE BROWSER: get_image_files returned {len(image_files) if image_files else 0} files")
 
             if not image_files:
                 self.info_label.setText("No images found")
@@ -699,8 +711,10 @@ class ImageBrowserWidget(QWidget):
                     metadata.update(parsed)
                 self.all_images[filename] = metadata
 
+            logger.info(f"IMAGE BROWSER: Built all_images dict with {len(self.all_images)} entries")
+
         except Exception as e:
-            logger.error(f"Failed to load images: {e}")
+            logger.error(f"Failed to load images: {e}", exc_info=True)
             QMessageBox.warning(self, "Error", f"Failed to load images: {e}")
             self.info_label.setText("Error loading images")
             self.all_images = {}
@@ -1158,7 +1172,7 @@ class ImageBrowserWidget(QWidget):
         if global_config.vfs_config.read_backend != Backend.AUTO:
             read_backend = global_config.vfs_config.read_backend.value
         else:
-            read_backend = self.orchestrator.microscope_handler.get_primary_backend(plate_path)
+            read_backend = self.orchestrator.microscope_handler.get_primary_backend(plate_path, self.orchestrator.filemanager)
 
         # Resolve Napari config (lightweight operation, safe in UI thread)
         from openhcs.config_framework.context_manager import config_context
@@ -1179,7 +1193,7 @@ class ImageBrowserWidget(QWidget):
             viewer, filenames, plate_path, read_backend, napari_config
         )
 
-        logger.info(f"Loading and streaming batch of {len(filenames)} images to Napari viewer on port {napari_config.napari_port}...")
+        logger.info(f"Loading and streaming batch of {len(filenames)} images to Napari viewer on port {napari_config.port}...")
 
     def _load_and_stream_batch_to_fiji(self, filenames: list):
         """Load multiple images and stream as batch to Fiji (builds hyperstack)."""
@@ -1197,7 +1211,7 @@ class ImageBrowserWidget(QWidget):
         if global_config.vfs_config.read_backend != Backend.AUTO:
             read_backend = global_config.vfs_config.read_backend.value
         else:
-            read_backend = self.orchestrator.microscope_handler.get_primary_backend(plate_path)
+            read_backend = self.orchestrator.microscope_handler.get_primary_backend(plate_path, self.orchestrator.filemanager)
 
         # Resolve Fiji config (lightweight operation, safe in UI thread)
         from openhcs.config_framework.context_manager import config_context
@@ -1219,7 +1233,7 @@ class ImageBrowserWidget(QWidget):
             viewer, filenames, plate_path, read_backend, fiji_config
         )
 
-        logger.info(f"Loading and streaming batch of {len(filenames)} images to Fiji viewer on port {fiji_config.fiji_port}...")
+        logger.info(f"Loading and streaming batch of {len(filenames)} images to Fiji viewer on port {fiji_config.port}...")
 
     def _load_and_stream_batch_to_napari_async(self, viewer, filenames: list, plate_path: Path,
                                                  read_backend: str, config):
@@ -1238,8 +1252,8 @@ class ImageBrowserWidget(QWidget):
 
                 if not is_already_running:
                     # Viewer is launching - register it immediately so UI shows it
-                    register_launching_viewer(viewer.napari_port, 'napari', len(filenames))
-                    logger.info(f"Registered launching Napari viewer on port {viewer.napari_port} with {len(filenames)} queued images")
+                    register_launching_viewer(viewer.port, 'napari', len(filenames))
+                    logger.info(f"Registered launching Napari viewer on port {viewer.port} with {len(filenames)} queued images")
 
                 # Show loading status
                 self._update_status_threadsafe(f"Loading {len(filenames)} images from disk...")
@@ -1261,29 +1275,32 @@ class ImageBrowserWidget(QWidget):
 
                 if not is_already_running:
                     # Viewer is launching - wait for it to be ready before streaming
-                    logger.info(f"Waiting for Napari viewer on port {viewer.napari_port} to be ready...")
+                    logger.info(f"Waiting for Napari viewer on port {viewer.port} to be ready...")
 
                     # Wait for viewer to be ready before streaming
                     if not viewer.wait_for_ready(timeout=15.0):
-                        unregister_launching_viewer(viewer.napari_port)
-                        raise RuntimeError(f"Napari viewer on port {viewer.napari_port} failed to become ready")
+                        unregister_launching_viewer(viewer.port)
+                        raise RuntimeError(f"Napari viewer on port {viewer.port} failed to become ready")
 
-                    logger.info(f"Napari viewer on port {viewer.napari_port} is ready")
+                    logger.info(f"Napari viewer on port {viewer.port} is ready")
                     # Unregister from launching registry (now ready)
-                    unregister_launching_viewer(viewer.napari_port)
+                    unregister_launching_viewer(viewer.port)
                 else:
-                    logger.info(f"Napari viewer on port {viewer.napari_port} is already running")
+                    logger.info(f"Napari viewer on port {viewer.port} is already running")
 
                 # Use the napari streaming backend to send the batch
                 from openhcs.constants.constants import Backend as BackendEnum
 
+                # Build source from subdirectory name (image viewer context)
+                # Use first file path to determine subdirectory
+                source = Path(file_paths[0]).parent.name if file_paths else 'unknown_source'
+
                 # Prepare metadata for streaming
                 metadata = {
-                    'napari_port': viewer.napari_port,
+                    'port': viewer.port,
                     'display_config': config,
                     'microscope_handler': self.orchestrator.microscope_handler,
-                    'step_index': 0,
-                    'step_name': 'image_browser'
+                    'source': source
                 }
 
                 # Stream batch to Napari
@@ -1293,7 +1310,7 @@ class ImageBrowserWidget(QWidget):
                     BackendEnum.NAPARI_STREAM.value,
                     **metadata
                 )
-                logger.info(f"Successfully streamed batch of {len(file_paths)} images to Napari on port {viewer.napari_port}")
+                logger.info(f"Successfully streamed batch of {len(file_paths)} images to Napari on port {viewer.port}")
             except Exception as e:
                 logger.error(f"Failed to load/stream batch to Napari: {e}")
                 # Show error in UI thread
@@ -1326,30 +1343,33 @@ class ImageBrowserWidget(QWidget):
 
                 if not is_already_running:
                     # Viewer is launching - register it and show in UI
-                    register_launching_viewer(viewer.napari_port, 'napari', len(file_paths))
-                    logger.info(f"Waiting for Napari viewer on port {viewer.napari_port} to be ready...")
+                    register_launching_viewer(viewer.port, 'napari', len(file_paths))
+                    logger.info(f"Waiting for Napari viewer on port {viewer.port} to be ready...")
 
                     # Wait for viewer to be ready before streaming
                     if not viewer.wait_for_ready(timeout=15.0):
-                        unregister_launching_viewer(viewer.napari_port)
-                        raise RuntimeError(f"Napari viewer on port {viewer.napari_port} failed to become ready")
+                        unregister_launching_viewer(viewer.port)
+                        raise RuntimeError(f"Napari viewer on port {viewer.port} failed to become ready")
 
-                    logger.info(f"Napari viewer on port {viewer.napari_port} is ready")
+                    logger.info(f"Napari viewer on port {viewer.port} is ready")
                     # Unregister from launching registry (now ready)
-                    unregister_launching_viewer(viewer.napari_port)
+                    unregister_launching_viewer(viewer.port)
                 else:
-                    logger.info(f"Napari viewer on port {viewer.napari_port} is already running")
+                    logger.info(f"Napari viewer on port {viewer.port} is already running")
 
                 # Use the napari streaming backend to send the batch
                 from openhcs.constants.constants import Backend as BackendEnum
 
+                # Build source from subdirectory name (image viewer context)
+                # Use first file path to determine subdirectory
+                source = Path(file_paths[0]).parent.name if file_paths else 'unknown_source'
+
                 # Prepare metadata for streaming
                 metadata = {
-                    'napari_port': viewer.napari_port,
+                    'port': viewer.port,
                     'display_config': config,
                     'microscope_handler': self.orchestrator.microscope_handler,
-                    'step_index': 0,
-                    'step_name': 'image_browser'
+                    'source': source
                 }
 
                 # Stream batch to Napari
@@ -1359,7 +1379,7 @@ class ImageBrowserWidget(QWidget):
                     BackendEnum.NAPARI_STREAM.value,
                     **metadata
                 )
-                logger.info(f"Successfully streamed batch of {len(file_paths)} images to Napari on port {viewer.napari_port}")
+                logger.info(f"Successfully streamed batch of {len(file_paths)} images to Napari on port {viewer.port}")
             except Exception as e:
                 logger.error(f"Failed to stream batch to Napari: {e}")
                 # Show error in UI thread
@@ -1397,8 +1417,8 @@ class ImageBrowserWidget(QWidget):
 
                 if not is_already_running:
                     # Viewer is launching - register it immediately so UI shows it
-                    register_launching_viewer(viewer.fiji_port, 'fiji', len(filenames))
-                    logger.info(f"Registered launching Fiji viewer on port {viewer.fiji_port} with {len(filenames)} queued images")
+                    register_launching_viewer(viewer.port, 'fiji', len(filenames))
+                    logger.info(f"Registered launching Fiji viewer on port {viewer.port} with {len(filenames)} queued images")
 
                 # Show loading status
                 self._update_status_threadsafe(f"Loading {len(filenames)} images from disk...")
@@ -1420,29 +1440,32 @@ class ImageBrowserWidget(QWidget):
 
                 if not is_already_running:
                     # Viewer is launching - wait for it to be ready before streaming
-                    logger.info(f"Waiting for Fiji viewer on port {viewer.fiji_port} to be ready...")
+                    logger.info(f"Waiting for Fiji viewer on port {viewer.port} to be ready...")
 
                     # Wait for viewer to be ready before streaming
                     if not viewer.wait_for_ready(timeout=15.0):
-                        unregister_launching_viewer(viewer.fiji_port)
-                        raise RuntimeError(f"Fiji viewer on port {viewer.fiji_port} failed to become ready")
+                        unregister_launching_viewer(viewer.port)
+                        raise RuntimeError(f"Fiji viewer on port {viewer.port} failed to become ready")
 
-                    logger.info(f"Fiji viewer on port {viewer.fiji_port} is ready")
+                    logger.info(f"Fiji viewer on port {viewer.port} is ready")
                     # Unregister from launching registry (now ready)
-                    unregister_launching_viewer(viewer.fiji_port)
+                    unregister_launching_viewer(viewer.port)
                 else:
-                    logger.info(f"Fiji viewer on port {viewer.fiji_port} is already running")
+                    logger.info(f"Fiji viewer on port {viewer.port} is already running")
 
                 # Use the Fiji streaming backend to send the batch
                 from openhcs.constants.constants import Backend as BackendEnum
 
+                # Build source from subdirectory name (image viewer context)
+                # Use first file path to determine subdirectory
+                source = Path(file_paths[0]).parent.name if file_paths else 'unknown_source'
+
                 # Prepare metadata for streaming
                 metadata = {
-                    'fiji_port': viewer.fiji_port,
+                    'port': viewer.port,
                     'display_config': config,
                     'microscope_handler': self.orchestrator.microscope_handler,
-                    'step_index': 0,
-                    'step_name': 'image_browser'
+                    'source': source
                 }
 
                 # Stream batch to Fiji
@@ -1453,7 +1476,7 @@ class ImageBrowserWidget(QWidget):
                     BackendEnum.FIJI_STREAM.value,
                     **metadata
                 )
-                logger.info(f"✅ IMAGE BROWSER: Successfully streamed batch of {len(file_paths)} images to Fiji on port {viewer.fiji_port}")
+                logger.info(f"✅ IMAGE BROWSER: Successfully streamed batch of {len(file_paths)} images to Fiji on port {viewer.port}")
             except Exception as e:
                 logger.error(f"Failed to load/stream batch to Fiji: {e}")
                 # Show error in UI thread
@@ -1486,30 +1509,33 @@ class ImageBrowserWidget(QWidget):
 
                 if not is_already_running:
                     # Viewer is launching - register it and show in UI
-                    register_launching_viewer(viewer.fiji_port, 'fiji', len(file_paths))
-                    logger.info(f"Waiting for Fiji viewer on port {viewer.fiji_port} to be ready...")
+                    register_launching_viewer(viewer.port, 'fiji', len(file_paths))
+                    logger.info(f"Waiting for Fiji viewer on port {viewer.port} to be ready...")
 
                     # Wait for viewer to be ready before streaming
                     if not viewer.wait_for_ready(timeout=15.0):
-                        unregister_launching_viewer(viewer.fiji_port)
-                        raise RuntimeError(f"Fiji viewer on port {viewer.fiji_port} failed to become ready")
+                        unregister_launching_viewer(viewer.port)
+                        raise RuntimeError(f"Fiji viewer on port {viewer.port} failed to become ready")
 
-                    logger.info(f"Fiji viewer on port {viewer.fiji_port} is ready")
+                    logger.info(f"Fiji viewer on port {viewer.port} is ready")
                     # Unregister from launching registry (now ready)
-                    unregister_launching_viewer(viewer.fiji_port)
+                    unregister_launching_viewer(viewer.port)
                 else:
-                    logger.info(f"Fiji viewer on port {viewer.fiji_port} is already running")
+                    logger.info(f"Fiji viewer on port {viewer.port} is already running")
 
                 # Use the Fiji streaming backend to send the batch
                 from openhcs.constants.constants import Backend as BackendEnum
 
+                # Build source from subdirectory name (image viewer context)
+                # Use first file path to determine subdirectory
+                source = Path(file_paths[0]).parent.name if file_paths else 'unknown_source'
+
                 # Prepare metadata for streaming
                 metadata = {
-                    'fiji_port': viewer.fiji_port,
+                    'port': viewer.port,
                     'display_config': config,
                     'microscope_handler': self.orchestrator.microscope_handler,
-                    'step_index': 0,
-                    'step_name': 'image_browser'
+                    'source': source
                 }
 
                 # Stream batch to Fiji
@@ -1519,7 +1545,7 @@ class ImageBrowserWidget(QWidget):
                     BackendEnum.FIJI_STREAM.value,
                     **metadata
                 )
-                logger.info(f"Successfully streamed batch of {len(file_paths)} images to Fiji on port {viewer.fiji_port}")
+                logger.info(f"Successfully streamed batch of {len(file_paths)} images to Fiji on port {viewer.port}")
             except Exception as e:
                 logger.error(f"Failed to stream batch to Fiji: {e}")
                 # Show error in UI thread
@@ -1561,19 +1587,23 @@ class ImageBrowserWidget(QWidget):
             # Stream ROIs using filemanager.save() - same as pipeline execution
             # Pass display_config and microscope_handler just like image streaming does
             from openhcs.constants.constants import Backend as BackendEnum
+            from pathlib import Path
+
+            # Build source from subdirectory name (image viewer context)
+            source = Path(roi_json_path).parent.name
+
             self.filemanager.save(
                 rois,
                 roi_json_path,
                 BackendEnum.NAPARI_STREAM.value,
-                napari_host='localhost',
-                napari_port=napari_config.napari_port,
+                host='localhost',
+                port=napari_config.port,
                 display_config=napari_config,
                 microscope_handler=self.orchestrator.microscope_handler,
-                step_index=0,
-                step_name='image_browser'
+                source=source
             )
 
-            logger.info(f"Streamed {len(rois)} ROIs to Napari on port {napari_config.napari_port}")
+            logger.info(f"Streamed {len(rois)} ROIs to Napari on port {napari_config.port}")
 
         except Exception as e:
             logger.error(f"Failed to stream ROIs to Napari: {e}")
@@ -1600,19 +1630,23 @@ class ImageBrowserWidget(QWidget):
             # Stream ROIs using filemanager.save() - same as pipeline execution
             # Pass display_config and microscope_handler just like image streaming does
             from openhcs.constants.constants import Backend as BackendEnum
+            from pathlib import Path
+
+            # Build source from subdirectory name (image viewer context)
+            source = Path(roi_json_path).parent.name
+
             self.filemanager.save(
                 rois,
                 roi_json_path,
                 BackendEnum.FIJI_STREAM.value,
-                fiji_host='localhost',
-                fiji_port=fiji_config.fiji_port,
+                host='localhost',
+                port=fiji_config.port,
                 display_config=fiji_config,
                 microscope_handler=self.orchestrator.microscope_handler,
-                step_index=0,
-                step_name='image_browser'
+                source=source
             )
 
-            logger.info(f"Streamed {len(rois)} ROIs to Fiji on port {fiji_config.fiji_port}")
+            logger.info(f"Streamed {len(rois)} ROIs to Fiji on port {fiji_config.port}")
 
         except Exception as e:
             logger.error(f"Failed to stream ROIs to Fiji: {e}")
