@@ -15,6 +15,7 @@ from typing import Optional
 from pathlib import Path
 
 from openhcs.io.filemanager import FileManager
+from openhcs.core.config import TransportMode, FijiStreamingConfig
 
 logger = logging.getLogger(__name__)
 
@@ -41,12 +42,18 @@ def _cleanup_global_fiji_viewer() -> None:
             _global_fiji_process = None
 
 
-def _spawn_detached_fiji_process(port: int, viewer_title: str, display_config) -> subprocess.Popen:
+def _spawn_detached_fiji_process(port: int, viewer_title: str, display_config, transport_mode: TransportMode = TransportMode.IPC) -> subprocess.Popen:
     """
     Spawn a completely detached Fiji viewer process that survives parent termination.
 
     This creates a subprocess that runs independently and won't be terminated when
     the parent process exits, enabling true persistence across pipeline runs.
+
+    Args:
+        port: ZMQ port to listen on
+        viewer_title: Title for the Fiji viewer window
+        display_config: Display configuration
+        transport_mode: ZMQ transport mode (IPC or TCP)
     """
     import sys
     import os
@@ -68,7 +75,9 @@ sys.path.insert(0, "{current_dir}")
 
 try:
     from openhcs.runtime.fiji_viewer_server import _fiji_viewer_server_process
-    _fiji_viewer_server_process({port}, "{viewer_title}", None, "{current_dir}/.fiji_log_path_placeholder")
+    from openhcs.core.config import TransportMode
+    transport_mode = TransportMode.{transport_mode.name}
+    _fiji_viewer_server_process({port}, "{viewer_title}", None, "{current_dir}/.fiji_log_path_placeholder", transport_mode)
 except Exception as e:
     import logging
     logger = logging.getLogger("openhcs.runtime.fiji_detached")
@@ -139,13 +148,15 @@ class FijiStreamVisualizer:
     """
 
     def __init__(self, filemanager: FileManager, visualizer_config, viewer_title: str = "OpenHCS Fiji Visualization",
-                 persistent: bool = True, fiji_port: int = 5565, display_config=None):
+                 persistent: bool = True, port: int = None, display_config=None, transport_mode: TransportMode = TransportMode.IPC):
         self.filemanager = filemanager
         self.viewer_title = viewer_title
         self.persistent = persistent
         self.visualizer_config = visualizer_config
-        self.fiji_port = fiji_port
+        # Use config class default if not specified
+        self.port = port if port is not None else FijiStreamingConfig.__dataclass_fields__['port'].default
         self.display_config = display_config
+        self.transport_mode = transport_mode  # ZMQ transport mode (IPC or TCP)
         self.process: Optional[multiprocessing.Process] = None
         self._is_running = False
         self._connected_to_existing = False
@@ -166,7 +177,7 @@ class FijiStreamVisualizer:
         if self._connected_to_existing:
             # Quick ping check to verify viewer is still alive
             if not self._quick_ping_check():
-                logger.debug(f"🔬 FIJI VISUALIZER: Connected viewer on port {self.fiji_port} is no longer responsive")
+                logger.debug(f"🔬 FIJI VISUALIZER: Connected viewer on port {self.port} is no longer responsive")
                 self._is_running = False
                 self._connected_to_existing = False
                 return False
@@ -186,7 +197,7 @@ class FijiStreamVisualizer:
                 alive = self.process.poll() is None
 
             if not alive:
-                logger.debug(f"🔬 FIJI VISUALIZER: Fiji process on port {self.fiji_port} is no longer alive")
+                logger.debug(f"🔬 FIJI VISUALIZER: Fiji process on port {self.port} is no longer alive")
                 self._is_running = False
 
             return alive
@@ -199,13 +210,16 @@ class FijiStreamVisualizer:
         """Quick ping check to verify viewer is responsive (for connected viewers)."""
         import zmq
         import pickle
+        from openhcs.runtime.zmq_base import get_zmq_transport_url
+        from openhcs.constants.constants import CONTROL_PORT_OFFSET
 
         try:
             ctx = zmq.Context()
             sock = ctx.socket(zmq.REQ)
             sock.setsockopt(zmq.LINGER, 0)
             sock.setsockopt(zmq.RCVTIMEO, 200)  # 200ms timeout for quick check
-            sock.connect(f"tcp://localhost:{self.fiji_port + 1000}")
+            control_url = get_zmq_transport_url(self.port + CONTROL_PORT_OFFSET, self.transport_mode, 'localhost')
+            sock.connect(control_url)
             sock.send(pickle.dumps({'type': 'ping'}))
             response = pickle.loads(sock.recv())
             sock.close()
@@ -235,33 +249,33 @@ class FijiStreamVisualizer:
 
         with self._lock:
             # Check if there's already a viewer running on the configured port
-            if self._is_port_in_use(self.fiji_port):
+            if self._is_port_in_use(self.port):
                 # Try to connect to existing viewer first
-                logger.info(f"🔬 FIJI VISUALIZER: Port {self.fiji_port} is in use, attempting to connect to existing viewer...")
+                logger.info(f"🔬 FIJI VISUALIZER: Port {self.port} is in use, attempting to connect to existing viewer...")
                 if self._try_connect_to_existing_viewer():
-                    logger.info(f"🔬 FIJI VISUALIZER: Successfully connected to existing viewer on port {self.fiji_port}")
+                    logger.info(f"🔬 FIJI VISUALIZER: Successfully connected to existing viewer on port {self.port}")
                     self._is_running = True
                     self._connected_to_existing = True
                     return
                 else:
                     # Existing viewer is unresponsive - kill it and start fresh
-                    logger.info(f"🔬 FIJI VISUALIZER: Existing viewer on port {self.fiji_port} is unresponsive, killing and restarting...")
+                    logger.info(f"🔬 FIJI VISUALIZER: Existing viewer on port {self.port} is unresponsive, killing and restarting...")
                     from openhcs.runtime.zmq_base import ZMQServer
-                    ZMQServer.kill_processes_on_port(self.fiji_port)
-                    ZMQServer.kill_processes_on_port(self.fiji_port + 1000)
+                    ZMQServer.kill_processes_on_port(self.port)
+                    ZMQServer.kill_processes_on_port(self.port + 1000)
                     time.sleep(0.5)
 
             if self._is_running:
                 logger.warning("Fiji viewer is already running.")
                 return
 
-            logger.info(f"🔬 FIJI VISUALIZER: Starting Fiji viewer server on port {self.fiji_port} (persistent={self.persistent})")
+            logger.info(f"🔬 FIJI VISUALIZER: Starting Fiji viewer server on port {self.port} (persistent={self.persistent})")
 
             # ALL viewers (persistent and non-persistent) should be detached subprocess
             # so they don't block parent process exit. The difference is only whether
             # we terminate them during cleanup.
             logger.info(f"🔬 FIJI VISUALIZER: Creating {'persistent' if self.persistent else 'non-persistent'} Fiji viewer (detached)")
-            self.process = _spawn_detached_fiji_process(self.fiji_port, self.viewer_title, self.display_config)
+            self.process = _spawn_detached_fiji_process(self.port, self.viewer_title, self.display_config, self.transport_mode)
 
             # Only track non-persistent viewers in global variable for test cleanup
             if not self.persistent:
@@ -290,29 +304,40 @@ class FijiStreamVisualizer:
                     logger.error("🔬 FIJI VISUALIZER: Fiji viewer server failed to become ready")
 
     def _is_port_in_use(self, port: int) -> bool:
-        """Check if a port is in use."""
-        import socket
-        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        sock.settimeout(0.1)
-        try:
-            sock.bind(('localhost', port))
-            sock.close()
-            return False
-        except OSError:
-            sock.close()
-            return True
+        """Check if a port/socket is in use (handles both IPC and TCP modes)."""
+        from openhcs.runtime.zmq_base import _get_ipc_socket_path
+
+        if self.transport_mode == TransportMode.IPC:
+            # IPC mode - check if socket file exists
+            socket_path = _get_ipc_socket_path(port)
+            return socket_path.exists() if socket_path else False
+        else:
+            # TCP mode - check if port is bound
+            import socket
+            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            sock.settimeout(0.1)
+            try:
+                sock.bind(('localhost', port))
+                sock.close()
+                return False
+            except OSError:
+                sock.close()
+                return True
 
     def _try_connect_to_existing_viewer(self) -> bool:
         """Try to connect to an existing Fiji viewer and verify it's responsive."""
         import zmq
         import pickle
+        from openhcs.runtime.zmq_base import get_zmq_transport_url
+        from openhcs.constants.constants import CONTROL_PORT_OFFSET
 
         try:
             ctx = zmq.Context()
             sock = ctx.socket(zmq.REQ)
             sock.setsockopt(zmq.LINGER, 0)
             sock.setsockopt(zmq.RCVTIMEO, 500)  # 500ms timeout
-            sock.connect(f"tcp://localhost:{self.fiji_port + 1000}")
+            control_url = get_zmq_transport_url(self.port + CONTROL_PORT_OFFSET, self.transport_mode, 'localhost')
+            sock.connect(control_url)
 
             # Send ping
             sock.send(pickle.dumps({'type': 'ping'}))
@@ -329,8 +354,10 @@ class FijiStreamVisualizer:
         """Wait for Fiji server to be ready via ping/pong."""
         import zmq
         import pickle
+        from openhcs.runtime.zmq_base import get_zmq_transport_url
+        from openhcs.constants.constants import CONTROL_PORT_OFFSET
 
-        logger.info(f"🔬 FIJI VISUALIZER: Waiting for server on port {self.fiji_port} to be ready...")
+        logger.info(f"🔬 FIJI VISUALIZER: Waiting for server on port {self.port} to be ready...")
 
         start_time = time.time()
         while time.time() - start_time < timeout:
@@ -340,7 +367,8 @@ class FijiStreamVisualizer:
                 sock = ctx.socket(zmq.REQ)
                 sock.setsockopt(zmq.LINGER, 0)
                 sock.setsockopt(zmq.RCVTIMEO, 500)  # 500ms timeout
-                sock.connect(f"tcp://localhost:{self.fiji_port + 1000}")
+                control_url = get_zmq_transport_url(self.port + CONTROL_PORT_OFFSET, self.transport_mode, 'localhost')
+                sock.connect(control_url)
 
                 # Send ping
                 sock.send(pickle.dumps({'type': 'ping'}))
@@ -350,16 +378,90 @@ class FijiStreamVisualizer:
                 ctx.term()
 
                 if response.get('type') == 'pong':
-                    logger.info(f"🔬 FIJI VISUALIZER: Server ready on port {self.fiji_port}")
+                    logger.info(f"🔬 FIJI VISUALIZER: Server ready on port {self.port}")
                     return True
             except Exception as e:
                 logger.debug(f"🔬 FIJI VISUALIZER: Ping failed: {e}")
 
             time.sleep(0.2)
 
-        logger.warning(f"🔬 FIJI VISUALIZER: Timeout waiting for server on port {self.fiji_port}")
+        logger.warning(f"🔬 FIJI VISUALIZER: Timeout waiting for server on port {self.port}")
         return False
 
+    def send_control_message(self, message_type: str, timeout: float = 2.0) -> bool:
+        """
+        Send a control message to the Fiji viewer.
+
+        Args:
+            message_type: Type of control message ('clear_state', 'shutdown', etc.)
+            timeout: Timeout in seconds for waiting for response
+
+        Returns:
+            True if message was sent and acknowledged, False otherwise
+        """
+        if not self.is_running or self.port is None:
+            logger.warning(f"🔬 FIJI VISUALIZER: Cannot send {message_type} - viewer not running")
+            return False
+
+        import zmq
+        import pickle
+        from openhcs.runtime.zmq_base import get_zmq_transport_url
+        from openhcs.constants.constants import CONTROL_PORT_OFFSET
+
+        control_port = self.port + CONTROL_PORT_OFFSET
+        control_context = None
+        control_socket = None
+
+        try:
+            control_context = zmq.Context()
+            control_socket = control_context.socket(zmq.REQ)
+            control_socket.setsockopt(zmq.LINGER, 0)
+            control_socket.setsockopt(zmq.RCVTIMEO, int(timeout * 1000))
+            control_url = get_zmq_transport_url(control_port, self.transport_mode, 'localhost')
+            control_socket.connect(control_url)
+
+            # Send control message
+            message = {'type': message_type}
+            control_socket.send(pickle.dumps(message))
+
+            # Wait for acknowledgment
+            response = control_socket.recv()
+            response_data = pickle.loads(response)
+
+            if response_data.get('status') == 'success':
+                logger.info(f"🔬 FIJI VISUALIZER: {message_type} acknowledged by viewer")
+                return True
+            else:
+                logger.warning(f"🔬 FIJI VISUALIZER: {message_type} failed: {response_data}")
+                return False
+
+        except zmq.Again:
+            logger.warning(f"🔬 FIJI VISUALIZER: Timeout waiting for {message_type} acknowledgment")
+            return False
+        except Exception as e:
+            logger.warning(f"🔬 FIJI VISUALIZER: Failed to send {message_type}: {e}")
+            return False
+        finally:
+            if control_socket:
+                try:
+                    control_socket.close()
+                except Exception as e:
+                    logger.debug(f"Failed to close control socket: {e}")
+            if control_context:
+                try:
+                    control_context.term()
+                except Exception as e:
+                    logger.debug(f"Failed to terminate control context: {e}")
+
+    def clear_viewer_state(self) -> bool:
+        """
+        Clear accumulated viewer state (dimension values, hyperstack metadata) for a new pipeline run.
+
+        Returns:
+            True if state was cleared successfully, False otherwise
+        """
+        return self.send_control_message('clear_state')
+
     def stop_viewer(self) -> None:
         """Stop Fiji viewer server (only if not persistent)."""
         global _global_fiji_process
